@@ -5,13 +5,13 @@ use utf8;
 
 package CPAN::Changes::Dependencies::Details;
 
-our $VERSION = '0.001003';
+our $VERSION = '0.001004';
 
 # ABSTRACT: Create CPAN::Changes style file only containing dependency change information
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-use Moo qw( extends );
+use Moo qw( extends around );
 use MooX::Lsub qw( lsub );
 use Carp qw( croak );
 use CPAN::Changes::Release;
@@ -64,14 +64,15 @@ sub _mk_release {
   return $release_object;
 }
 
-sub add_release {
-  my ( $self, @releases ) = @_;
+around add_release => sub {
+  my ( $orig, $self, @releases ) = @_;
   for my $release (@releases) {
     my $release_object = $self->_mk_release($release);
-    $self->{'releases'}->{ $release_object->version } = $release_object;
+    $self->$orig($release_object);
   }
   return;
-}
+};
+
 no Moo;
 
 1;
@@ -88,7 +89,7 @@ CPAN::Changes::Dependencies::Details - Create CPAN::Changes style file only cont
 
 =head1 VERSION
 
-version 0.001003
+version 0.001004
 
 =head1 SYNOPSIS
 
